Power Consumption
=================

Classes for modeling power consumption and battery management.

.. module:: PASS.power_consumption

power_consumption_classes
-------------------------

Battery and instrument power modeling.

.. automodule:: PASS.power_consumption.power_consumption_classes
   :members:
   :undoc-members:
   :show-inheritance:

BatteryBank
^^^^^^^^^^^

.. autoclass:: PASS.power_consumption.power_consumption_classes.BatteryBank
   :members:
   :undoc-members:
   :show-inheritance:

Instrument
^^^^^^^^^^

.. autoclass:: PASS.power_consumption.power_consumption_classes.Instrument
   :members:
   :undoc-members:
   :show-inheritance:

power_capacitance
-----------------

Power capacity calculations.

.. automodule:: PASS.power_consumption.power_capacitance
   :members:
   :undoc-members:
   :show-inheritance:
